# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ParameterValue(object):
    """
    User defined value for a parameter.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ParameterValue object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param simple_value:
            The value to assign to the simple_value property of this ParameterValue.
        :type simple_value: object

        :param root_object_value:
            The value to assign to the root_object_value property of this ParameterValue.
        :type root_object_value: object

        """
        self.swagger_types = {
            'simple_value': 'object',
            'root_object_value': 'object'
        }

        self.attribute_map = {
            'simple_value': 'simpleValue',
            'root_object_value': 'rootObjectValue'
        }

        self._simple_value = None
        self._root_object_value = None

    @property
    def simple_value(self):
        """
        Gets the simple_value of this ParameterValue.
        A simple value for the parameter.


        :return: The simple_value of this ParameterValue.
        :rtype: object
        """
        return self._simple_value

    @simple_value.setter
    def simple_value(self, simple_value):
        """
        Sets the simple_value of this ParameterValue.
        A simple value for the parameter.


        :param simple_value: The simple_value of this ParameterValue.
        :type: object
        """
        self._simple_value = simple_value

    @property
    def root_object_value(self):
        """
        Gets the root_object_value of this ParameterValue.
        This can be any object such as a file entity, a schema, or a table.


        :return: The root_object_value of this ParameterValue.
        :rtype: object
        """
        return self._root_object_value

    @root_object_value.setter
    def root_object_value(self, root_object_value):
        """
        Sets the root_object_value of this ParameterValue.
        This can be any object such as a file entity, a schema, or a table.


        :param root_object_value: The root_object_value of this ParameterValue.
        :type: object
        """
        self._root_object_value = root_object_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateInstancePoolPlacementConfigurationDetails(object):
    """
    The location for where an instance pool will place instances.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateInstancePoolPlacementConfigurationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this CreateInstancePoolPlacementConfigurationDetails.
        :type availability_domain: str

        :param fault_domains:
            The value to assign to the fault_domains property of this CreateInstancePoolPlacementConfigurationDetails.
        :type fault_domains: list[str]

        :param primary_subnet_id:
            The value to assign to the primary_subnet_id property of this CreateInstancePoolPlacementConfigurationDetails.
        :type primary_subnet_id: str

        :param secondary_vnic_subnets:
            The value to assign to the secondary_vnic_subnets property of this CreateInstancePoolPlacementConfigurationDetails.
        :type secondary_vnic_subnets: list[oci.core.models.InstancePoolPlacementSecondaryVnicSubnet]

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'fault_domains': 'list[str]',
            'primary_subnet_id': 'str',
            'secondary_vnic_subnets': 'list[InstancePoolPlacementSecondaryVnicSubnet]'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'fault_domains': 'faultDomains',
            'primary_subnet_id': 'primarySubnetId',
            'secondary_vnic_subnets': 'secondaryVnicSubnets'
        }

        self._availability_domain = None
        self._fault_domains = None
        self._primary_subnet_id = None
        self._secondary_vnic_subnets = None

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this CreateInstancePoolPlacementConfigurationDetails.
        The availability domain to place instances.

        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this CreateInstancePoolPlacementConfigurationDetails.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this CreateInstancePoolPlacementConfigurationDetails.
        The availability domain to place instances.

        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this CreateInstancePoolPlacementConfigurationDetails.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def fault_domains(self):
        """
        Gets the fault_domains of this CreateInstancePoolPlacementConfigurationDetails.
        The fault domains to place instances.

        If you don't provide any values, the system makes a best effort to distribute
        instances across all fault domains based on capacity.

        To distribute the instances evenly across selected fault domains, provide a
        set of fault domains. For example, you might want instances to be evenly
        distributed if your applications require high availability.

        To get a list of fault domains, use the
        :func:`list_fault_domains` operation
        in the Identity and Access Management Service API.

        Example: `[FAULT-DOMAIN-1, FAULT-DOMAIN-2, FAULT-DOMAIN-3]`


        :return: The fault_domains of this CreateInstancePoolPlacementConfigurationDetails.
        :rtype: list[str]
        """
        return self._fault_domains

    @fault_domains.setter
    def fault_domains(self, fault_domains):
        """
        Sets the fault_domains of this CreateInstancePoolPlacementConfigurationDetails.
        The fault domains to place instances.

        If you don't provide any values, the system makes a best effort to distribute
        instances across all fault domains based on capacity.

        To distribute the instances evenly across selected fault domains, provide a
        set of fault domains. For example, you might want instances to be evenly
        distributed if your applications require high availability.

        To get a list of fault domains, use the
        :func:`list_fault_domains` operation
        in the Identity and Access Management Service API.

        Example: `[FAULT-DOMAIN-1, FAULT-DOMAIN-2, FAULT-DOMAIN-3]`


        :param fault_domains: The fault_domains of this CreateInstancePoolPlacementConfigurationDetails.
        :type: list[str]
        """
        self._fault_domains = fault_domains

    @property
    def primary_subnet_id(self):
        """
        **[Required]** Gets the primary_subnet_id of this CreateInstancePoolPlacementConfigurationDetails.
        The `OCID`__ of the primary subnet to place instances.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The primary_subnet_id of this CreateInstancePoolPlacementConfigurationDetails.
        :rtype: str
        """
        return self._primary_subnet_id

    @primary_subnet_id.setter
    def primary_subnet_id(self, primary_subnet_id):
        """
        Sets the primary_subnet_id of this CreateInstancePoolPlacementConfigurationDetails.
        The `OCID`__ of the primary subnet to place instances.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param primary_subnet_id: The primary_subnet_id of this CreateInstancePoolPlacementConfigurationDetails.
        :type: str
        """
        self._primary_subnet_id = primary_subnet_id

    @property
    def secondary_vnic_subnets(self):
        """
        Gets the secondary_vnic_subnets of this CreateInstancePoolPlacementConfigurationDetails.
        The set of secondary VNIC data for instances in the pool.


        :return: The secondary_vnic_subnets of this CreateInstancePoolPlacementConfigurationDetails.
        :rtype: list[oci.core.models.InstancePoolPlacementSecondaryVnicSubnet]
        """
        return self._secondary_vnic_subnets

    @secondary_vnic_subnets.setter
    def secondary_vnic_subnets(self, secondary_vnic_subnets):
        """
        Sets the secondary_vnic_subnets of this CreateInstancePoolPlacementConfigurationDetails.
        The set of secondary VNIC data for instances in the pool.


        :param secondary_vnic_subnets: The secondary_vnic_subnets of this CreateInstancePoolPlacementConfigurationDetails.
        :type: list[oci.core.models.InstancePoolPlacementSecondaryVnicSubnet]
        """
        self._secondary_vnic_subnets = secondary_vnic_subnets

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FleetSummary(object):
    """
    A summary of the inventory count grouped by database type and subtype, and the metrics that
    describe the aggregated usage of CPU, storage, and so on of all the databases in the fleet.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FleetSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param aggregated_metrics:
            The value to assign to the aggregated_metrics property of this FleetSummary.
        :type aggregated_metrics: list[oci.database_management.models.FleetMetricSummaryDefinition]

        :param inventory:
            The value to assign to the inventory property of this FleetSummary.
        :type inventory: list[oci.database_management.models.FleetStatusByCategory]

        """
        self.swagger_types = {
            'aggregated_metrics': 'list[FleetMetricSummaryDefinition]',
            'inventory': 'list[FleetStatusByCategory]'
        }

        self.attribute_map = {
            'aggregated_metrics': 'aggregatedMetrics',
            'inventory': 'inventory'
        }

        self._aggregated_metrics = None
        self._inventory = None

    @property
    def aggregated_metrics(self):
        """
        Gets the aggregated_metrics of this FleetSummary.
        A list of databases present in the fleet and their usage metrics.


        :return: The aggregated_metrics of this FleetSummary.
        :rtype: list[oci.database_management.models.FleetMetricSummaryDefinition]
        """
        return self._aggregated_metrics

    @aggregated_metrics.setter
    def aggregated_metrics(self, aggregated_metrics):
        """
        Sets the aggregated_metrics of this FleetSummary.
        A list of databases present in the fleet and their usage metrics.


        :param aggregated_metrics: The aggregated_metrics of this FleetSummary.
        :type: list[oci.database_management.models.FleetMetricSummaryDefinition]
        """
        self._aggregated_metrics = aggregated_metrics

    @property
    def inventory(self):
        """
        Gets the inventory of this FleetSummary.
        A list of the databases in the fleet, grouped by database type and subtype.


        :return: The inventory of this FleetSummary.
        :rtype: list[oci.database_management.models.FleetStatusByCategory]
        """
        return self._inventory

    @inventory.setter
    def inventory(self, inventory):
        """
        Sets the inventory of this FleetSummary.
        A list of the databases in the fleet, grouped by database type and subtype.


        :param inventory: The inventory of this FleetSummary.
        :type: list[oci.database_management.models.FleetStatusByCategory]
        """
        self._inventory = inventory

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateRoverEntitlementDetails(object):
    """
    Information required to update a RoverEntitlement.
    """

    #: A constant which can be used with the lifecycle_state property of a UpdateRoverEntitlementDetails.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a UpdateRoverEntitlementDetails.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a UpdateRoverEntitlementDetails.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a UpdateRoverEntitlementDetails.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a UpdateRoverEntitlementDetails.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a UpdateRoverEntitlementDetails.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateRoverEntitlementDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateRoverEntitlementDetails.
        :type display_name: str

        :param tenant_id:
            The value to assign to the tenant_id property of this UpdateRoverEntitlementDetails.
        :type tenant_id: str

        :param requestor_name:
            The value to assign to the requestor_name property of this UpdateRoverEntitlementDetails.
        :type requestor_name: str

        :param requestor_email:
            The value to assign to the requestor_email property of this UpdateRoverEntitlementDetails.
        :type requestor_email: str

        :param entitlement_details:
            The value to assign to the entitlement_details property of this UpdateRoverEntitlementDetails.
        :type entitlement_details: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this UpdateRoverEntitlementDetails.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"
        :type lifecycle_state: str

        :param lifecycle_state_details:
            The value to assign to the lifecycle_state_details property of this UpdateRoverEntitlementDetails.
        :type lifecycle_state_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateRoverEntitlementDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateRoverEntitlementDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this UpdateRoverEntitlementDetails.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'tenant_id': 'str',
            'requestor_name': 'str',
            'requestor_email': 'str',
            'entitlement_details': 'str',
            'lifecycle_state': 'str',
            'lifecycle_state_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'tenant_id': 'tenantId',
            'requestor_name': 'requestorName',
            'requestor_email': 'requestorEmail',
            'entitlement_details': 'entitlementDetails',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_state_details': 'lifecycleStateDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._display_name = None
        self._tenant_id = None
        self._requestor_name = None
        self._requestor_email = None
        self._entitlement_details = None
        self._lifecycle_state = None
        self._lifecycle_state_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateRoverEntitlementDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :return: The display_name of this UpdateRoverEntitlementDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateRoverEntitlementDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this UpdateRoverEntitlementDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def tenant_id(self):
        """
        Gets the tenant_id of this UpdateRoverEntitlementDetails.
        tenant Id.


        :return: The tenant_id of this UpdateRoverEntitlementDetails.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """
        Sets the tenant_id of this UpdateRoverEntitlementDetails.
        tenant Id.


        :param tenant_id: The tenant_id of this UpdateRoverEntitlementDetails.
        :type: str
        """
        self._tenant_id = tenant_id

    @property
    def requestor_name(self):
        """
        Gets the requestor_name of this UpdateRoverEntitlementDetails.
        Requestor name for the entitlement.


        :return: The requestor_name of this UpdateRoverEntitlementDetails.
        :rtype: str
        """
        return self._requestor_name

    @requestor_name.setter
    def requestor_name(self, requestor_name):
        """
        Sets the requestor_name of this UpdateRoverEntitlementDetails.
        Requestor name for the entitlement.


        :param requestor_name: The requestor_name of this UpdateRoverEntitlementDetails.
        :type: str
        """
        self._requestor_name = requestor_name

    @property
    def requestor_email(self):
        """
        Gets the requestor_email of this UpdateRoverEntitlementDetails.
        Requestor email for the entitlement.


        :return: The requestor_email of this UpdateRoverEntitlementDetails.
        :rtype: str
        """
        return self._requestor_email

    @requestor_email.setter
    def requestor_email(self, requestor_email):
        """
        Sets the requestor_email of this UpdateRoverEntitlementDetails.
        Requestor email for the entitlement.


        :param requestor_email: The requestor_email of this UpdateRoverEntitlementDetails.
        :type: str
        """
        self._requestor_email = requestor_email

    @property
    def entitlement_details(self):
        """
        Gets the entitlement_details of this UpdateRoverEntitlementDetails.
        Details about the entitlement.


        :return: The entitlement_details of this UpdateRoverEntitlementDetails.
        :rtype: str
        """
        return self._entitlement_details

    @entitlement_details.setter
    def entitlement_details(self, entitlement_details):
        """
        Sets the entitlement_details of this UpdateRoverEntitlementDetails.
        Details about the entitlement.


        :param entitlement_details: The entitlement_details of this UpdateRoverEntitlementDetails.
        :type: str
        """
        self._entitlement_details = entitlement_details

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this UpdateRoverEntitlementDetails.
        The current state of the RoverNode.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"


        :return: The lifecycle_state of this UpdateRoverEntitlementDetails.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this UpdateRoverEntitlementDetails.
        The current state of the RoverNode.


        :param lifecycle_state: The lifecycle_state of this UpdateRoverEntitlementDetails.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            raise ValueError(
                "Invalid value for `lifecycle_state`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_state_details(self):
        """
        Gets the lifecycle_state_details of this UpdateRoverEntitlementDetails.
        A property that can contain details on the lifecycle.


        :return: The lifecycle_state_details of this UpdateRoverEntitlementDetails.
        :rtype: str
        """
        return self._lifecycle_state_details

    @lifecycle_state_details.setter
    def lifecycle_state_details(self, lifecycle_state_details):
        """
        Sets the lifecycle_state_details of this UpdateRoverEntitlementDetails.
        A property that can contain details on the lifecycle.


        :param lifecycle_state_details: The lifecycle_state_details of this UpdateRoverEntitlementDetails.
        :type: str
        """
        self._lifecycle_state_details = lifecycle_state_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateRoverEntitlementDetails.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateRoverEntitlementDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateRoverEntitlementDetails.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateRoverEntitlementDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateRoverEntitlementDetails.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateRoverEntitlementDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateRoverEntitlementDetails.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateRoverEntitlementDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this UpdateRoverEntitlementDetails.
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this UpdateRoverEntitlementDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this UpdateRoverEntitlementDetails.
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this UpdateRoverEntitlementDetails.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AwrDbParameterChangeSummary(object):
    """
    A summary of the changes made to a single AWR database parameter.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AwrDbParameterChangeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_begin:
            The value to assign to the time_begin property of this AwrDbParameterChangeSummary.
        :type time_begin: datetime

        :param time_end:
            The value to assign to the time_end property of this AwrDbParameterChangeSummary.
        :type time_end: datetime

        :param instance_number:
            The value to assign to the instance_number property of this AwrDbParameterChangeSummary.
        :type instance_number: int

        :param previous_value:
            The value to assign to the previous_value property of this AwrDbParameterChangeSummary.
        :type previous_value: str

        :param value:
            The value to assign to the value property of this AwrDbParameterChangeSummary.
        :type value: str

        :param snapshot_id:
            The value to assign to the snapshot_id property of this AwrDbParameterChangeSummary.
        :type snapshot_id: int

        :param value_modified:
            The value to assign to the value_modified property of this AwrDbParameterChangeSummary.
        :type value_modified: str

        :param is_default:
            The value to assign to the is_default property of this AwrDbParameterChangeSummary.
        :type is_default: bool

        """
        self.swagger_types = {
            'time_begin': 'datetime',
            'time_end': 'datetime',
            'instance_number': 'int',
            'previous_value': 'str',
            'value': 'str',
            'snapshot_id': 'int',
            'value_modified': 'str',
            'is_default': 'bool'
        }

        self.attribute_map = {
            'time_begin': 'timeBegin',
            'time_end': 'timeEnd',
            'instance_number': 'instanceNumber',
            'previous_value': 'previousValue',
            'value': 'value',
            'snapshot_id': 'snapshotId',
            'value_modified': 'valueModified',
            'is_default': 'isDefault'
        }

        self._time_begin = None
        self._time_end = None
        self._instance_number = None
        self._previous_value = None
        self._value = None
        self._snapshot_id = None
        self._value_modified = None
        self._is_default = None

    @property
    def time_begin(self):
        """
        Gets the time_begin of this AwrDbParameterChangeSummary.
        The start time of the interval.


        :return: The time_begin of this AwrDbParameterChangeSummary.
        :rtype: datetime
        """
        return self._time_begin

    @time_begin.setter
    def time_begin(self, time_begin):
        """
        Sets the time_begin of this AwrDbParameterChangeSummary.
        The start time of the interval.


        :param time_begin: The time_begin of this AwrDbParameterChangeSummary.
        :type: datetime
        """
        self._time_begin = time_begin

    @property
    def time_end(self):
        """
        Gets the time_end of this AwrDbParameterChangeSummary.
        The end time of the interval.


        :return: The time_end of this AwrDbParameterChangeSummary.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this AwrDbParameterChangeSummary.
        The end time of the interval.


        :param time_end: The time_end of this AwrDbParameterChangeSummary.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def instance_number(self):
        """
        Gets the instance_number of this AwrDbParameterChangeSummary.
        The database instance number.


        :return: The instance_number of this AwrDbParameterChangeSummary.
        :rtype: int
        """
        return self._instance_number

    @instance_number.setter
    def instance_number(self, instance_number):
        """
        Sets the instance_number of this AwrDbParameterChangeSummary.
        The database instance number.


        :param instance_number: The instance_number of this AwrDbParameterChangeSummary.
        :type: int
        """
        self._instance_number = instance_number

    @property
    def previous_value(self):
        """
        Gets the previous_value of this AwrDbParameterChangeSummary.
        The previous value of the database parameter.


        :return: The previous_value of this AwrDbParameterChangeSummary.
        :rtype: str
        """
        return self._previous_value

    @previous_value.setter
    def previous_value(self, previous_value):
        """
        Sets the previous_value of this AwrDbParameterChangeSummary.
        The previous value of the database parameter.


        :param previous_value: The previous_value of this AwrDbParameterChangeSummary.
        :type: str
        """
        self._previous_value = previous_value

    @property
    def value(self):
        """
        Gets the value of this AwrDbParameterChangeSummary.
        The current value of the database parameter.


        :return: The value of this AwrDbParameterChangeSummary.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this AwrDbParameterChangeSummary.
        The current value of the database parameter.


        :param value: The value of this AwrDbParameterChangeSummary.
        :type: str
        """
        self._value = value

    @property
    def snapshot_id(self):
        """
        **[Required]** Gets the snapshot_id of this AwrDbParameterChangeSummary.
        The ID of the snapshot with the parameter value changed. The snapshot ID is not the `OCID`__.
        It can be retrieved from the following endpoint:
        /managedDatabases/{managedDatabaseId}/awrDbs/{awrDbId}/awrDbSnapshots

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The snapshot_id of this AwrDbParameterChangeSummary.
        :rtype: int
        """
        return self._snapshot_id

    @snapshot_id.setter
    def snapshot_id(self, snapshot_id):
        """
        Sets the snapshot_id of this AwrDbParameterChangeSummary.
        The ID of the snapshot with the parameter value changed. The snapshot ID is not the `OCID`__.
        It can be retrieved from the following endpoint:
        /managedDatabases/{managedDatabaseId}/awrDbs/{awrDbId}/awrDbSnapshots

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param snapshot_id: The snapshot_id of this AwrDbParameterChangeSummary.
        :type: int
        """
        self._snapshot_id = snapshot_id

    @property
    def value_modified(self):
        """
        Gets the value_modified of this AwrDbParameterChangeSummary.
        Indicates whether the parameter has been modified after instance startup:
         - MODIFIED - Parameter has been modified with ALTER SESSION
         - SYSTEM_MOD - Parameter has been modified with ALTER SYSTEM (which causes all the currently logged in sessions\u2019 values to be modified)
         - FALSE - Parameter has not been modified after instance startup


        :return: The value_modified of this AwrDbParameterChangeSummary.
        :rtype: str
        """
        return self._value_modified

    @value_modified.setter
    def value_modified(self, value_modified):
        """
        Sets the value_modified of this AwrDbParameterChangeSummary.
        Indicates whether the parameter has been modified after instance startup:
         - MODIFIED - Parameter has been modified with ALTER SESSION
         - SYSTEM_MOD - Parameter has been modified with ALTER SYSTEM (which causes all the currently logged in sessions\u2019 values to be modified)
         - FALSE - Parameter has not been modified after instance startup


        :param value_modified: The value_modified of this AwrDbParameterChangeSummary.
        :type: str
        """
        self._value_modified = value_modified

    @property
    def is_default(self):
        """
        Gets the is_default of this AwrDbParameterChangeSummary.
        Indicates whether the parameter value in the end snapshot is the default.


        :return: The is_default of this AwrDbParameterChangeSummary.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """
        Sets the is_default of this AwrDbParameterChangeSummary.
        Indicates whether the parameter value in the end snapshot is the default.


        :param is_default: The is_default of this AwrDbParameterChangeSummary.
        :type: bool
        """
        self._is_default = is_default

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApplicationUsage(object):
    """
    Application usage during a specified time period.
    An application is a Java application that can be executed by a Java Runtime installation.
    An application is independent of the Java Runtime or its installation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApplicationUsage object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param application_id:
            The value to assign to the application_id property of this ApplicationUsage.
        :type application_id: str

        :param display_name:
            The value to assign to the display_name property of this ApplicationUsage.
        :type display_name: str

        :param application_type:
            The value to assign to the application_type property of this ApplicationUsage.
        :type application_type: str

        :param operating_systems:
            The value to assign to the operating_systems property of this ApplicationUsage.
        :type operating_systems: list[oci.jms.models.OperatingSystem]

        :param approximate_installation_count:
            The value to assign to the approximate_installation_count property of this ApplicationUsage.
        :type approximate_installation_count: int

        :param approximate_jre_count:
            The value to assign to the approximate_jre_count property of this ApplicationUsage.
        :type approximate_jre_count: int

        :param approximate_managed_instance_count:
            The value to assign to the approximate_managed_instance_count property of this ApplicationUsage.
        :type approximate_managed_instance_count: int

        :param time_start:
            The value to assign to the time_start property of this ApplicationUsage.
        :type time_start: datetime

        :param time_end:
            The value to assign to the time_end property of this ApplicationUsage.
        :type time_end: datetime

        :param time_first_seen:
            The value to assign to the time_first_seen property of this ApplicationUsage.
        :type time_first_seen: datetime

        :param time_last_seen:
            The value to assign to the time_last_seen property of this ApplicationUsage.
        :type time_last_seen: datetime

        """
        self.swagger_types = {
            'application_id': 'str',
            'display_name': 'str',
            'application_type': 'str',
            'operating_systems': 'list[OperatingSystem]',
            'approximate_installation_count': 'int',
            'approximate_jre_count': 'int',
            'approximate_managed_instance_count': 'int',
            'time_start': 'datetime',
            'time_end': 'datetime',
            'time_first_seen': 'datetime',
            'time_last_seen': 'datetime'
        }

        self.attribute_map = {
            'application_id': 'applicationId',
            'display_name': 'displayName',
            'application_type': 'applicationType',
            'operating_systems': 'operatingSystems',
            'approximate_installation_count': 'approximateInstallationCount',
            'approximate_jre_count': 'approximateJreCount',
            'approximate_managed_instance_count': 'approximateManagedInstanceCount',
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'time_first_seen': 'timeFirstSeen',
            'time_last_seen': 'timeLastSeen'
        }

        self._application_id = None
        self._display_name = None
        self._application_type = None
        self._operating_systems = None
        self._approximate_installation_count = None
        self._approximate_jre_count = None
        self._approximate_managed_instance_count = None
        self._time_start = None
        self._time_end = None
        self._time_first_seen = None
        self._time_last_seen = None

    @property
    def application_id(self):
        """
        **[Required]** Gets the application_id of this ApplicationUsage.
        An internal identifier for the application that is unique to a Fleet.


        :return: The application_id of this ApplicationUsage.
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """
        Sets the application_id of this ApplicationUsage.
        An internal identifier for the application that is unique to a Fleet.


        :param application_id: The application_id of this ApplicationUsage.
        :type: str
        """
        self._application_id = application_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ApplicationUsage.
        The name of the application.


        :return: The display_name of this ApplicationUsage.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ApplicationUsage.
        The name of the application.


        :param display_name: The display_name of this ApplicationUsage.
        :type: str
        """
        self._display_name = display_name

    @property
    def application_type(self):
        """
        **[Required]** Gets the application_type of this ApplicationUsage.
        The type of the application, denoted by how the application was started.


        :return: The application_type of this ApplicationUsage.
        :rtype: str
        """
        return self._application_type

    @application_type.setter
    def application_type(self, application_type):
        """
        Sets the application_type of this ApplicationUsage.
        The type of the application, denoted by how the application was started.


        :param application_type: The application_type of this ApplicationUsage.
        :type: str
        """
        self._application_type = application_type

    @property
    def operating_systems(self):
        """
        Gets the operating_systems of this ApplicationUsage.
        The operating systems running this application.


        :return: The operating_systems of this ApplicationUsage.
        :rtype: list[oci.jms.models.OperatingSystem]
        """
        return self._operating_systems

    @operating_systems.setter
    def operating_systems(self, operating_systems):
        """
        Sets the operating_systems of this ApplicationUsage.
        The operating systems running this application.


        :param operating_systems: The operating_systems of this ApplicationUsage.
        :type: list[oci.jms.models.OperatingSystem]
        """
        self._operating_systems = operating_systems

    @property
    def approximate_installation_count(self):
        """
        Gets the approximate_installation_count of this ApplicationUsage.
        The approximate count of installations running this application.


        :return: The approximate_installation_count of this ApplicationUsage.
        :rtype: int
        """
        return self._approximate_installation_count

    @approximate_installation_count.setter
    def approximate_installation_count(self, approximate_installation_count):
        """
        Sets the approximate_installation_count of this ApplicationUsage.
        The approximate count of installations running this application.


        :param approximate_installation_count: The approximate_installation_count of this ApplicationUsage.
        :type: int
        """
        self._approximate_installation_count = approximate_installation_count

    @property
    def approximate_jre_count(self):
        """
        Gets the approximate_jre_count of this ApplicationUsage.
        The approximate count of Java Runtimes running this application.


        :return: The approximate_jre_count of this ApplicationUsage.
        :rtype: int
        """
        return self._approximate_jre_count

    @approximate_jre_count.setter
    def approximate_jre_count(self, approximate_jre_count):
        """
        Sets the approximate_jre_count of this ApplicationUsage.
        The approximate count of Java Runtimes running this application.


        :param approximate_jre_count: The approximate_jre_count of this ApplicationUsage.
        :type: int
        """
        self._approximate_jre_count = approximate_jre_count

    @property
    def approximate_managed_instance_count(self):
        """
        Gets the approximate_managed_instance_count of this ApplicationUsage.
        The approximate count of managed instances reporting this application.


        :return: The approximate_managed_instance_count of this ApplicationUsage.
        :rtype: int
        """
        return self._approximate_managed_instance_count

    @approximate_managed_instance_count.setter
    def approximate_managed_instance_count(self, approximate_managed_instance_count):
        """
        Sets the approximate_managed_instance_count of this ApplicationUsage.
        The approximate count of managed instances reporting this application.


        :param approximate_managed_instance_count: The approximate_managed_instance_count of this ApplicationUsage.
        :type: int
        """
        self._approximate_managed_instance_count = approximate_managed_instance_count

    @property
    def time_start(self):
        """
        Gets the time_start of this ApplicationUsage.
        Lower bound of the specified time period filter.


        :return: The time_start of this ApplicationUsage.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this ApplicationUsage.
        Lower bound of the specified time period filter.


        :param time_start: The time_start of this ApplicationUsage.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        Gets the time_end of this ApplicationUsage.
        Upper bound of the specified time period filter.


        :return: The time_end of this ApplicationUsage.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this ApplicationUsage.
        Upper bound of the specified time period filter.


        :param time_end: The time_end of this ApplicationUsage.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def time_first_seen(self):
        """
        Gets the time_first_seen of this ApplicationUsage.
        The date and time the resource was _first_ reported to JMS.
        This is potentially _before_ the specified time period provided by the filters.
        For example, a resource can be first reported to JMS before the start of a specified time period,
        if it is also reported during the time period.


        :return: The time_first_seen of this ApplicationUsage.
        :rtype: datetime
        """
        return self._time_first_seen

    @time_first_seen.setter
    def time_first_seen(self, time_first_seen):
        """
        Sets the time_first_seen of this ApplicationUsage.
        The date and time the resource was _first_ reported to JMS.
        This is potentially _before_ the specified time period provided by the filters.
        For example, a resource can be first reported to JMS before the start of a specified time period,
        if it is also reported during the time period.


        :param time_first_seen: The time_first_seen of this ApplicationUsage.
        :type: datetime
        """
        self._time_first_seen = time_first_seen

    @property
    def time_last_seen(self):
        """
        Gets the time_last_seen of this ApplicationUsage.
        The date and time the resource was _last_ reported to JMS.
        This is potentially _after_ the specified time period provided by the filters.
        For example, a resource can be last reported to JMS before the start of a specified time period,
        if it is also reported during the time period.


        :return: The time_last_seen of this ApplicationUsage.
        :rtype: datetime
        """
        return self._time_last_seen

    @time_last_seen.setter
    def time_last_seen(self, time_last_seen):
        """
        Sets the time_last_seen of this ApplicationUsage.
        The date and time the resource was _last_ reported to JMS.
        This is potentially _after_ the specified time period provided by the filters.
        For example, a resource can be last reported to JMS before the start of a specified time period,
        if it is also reported during the time period.


        :param time_last_seen: The time_last_seen of this ApplicationUsage.
        :type: datetime
        """
        self._time_last_seen = time_last_seen

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlInsightThresholds(object):
    """
    Inventory details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlInsightThresholds object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param degradation_in_pct:
            The value to assign to the degradation_in_pct property of this SqlInsightThresholds.
        :type degradation_in_pct: int

        :param variability:
            The value to assign to the variability property of this SqlInsightThresholds.
        :type variability: float

        :param inefficiency_in_pct:
            The value to assign to the inefficiency_in_pct property of this SqlInsightThresholds.
        :type inefficiency_in_pct: int

        :param increase_in_io_in_pct:
            The value to assign to the increase_in_io_in_pct property of this SqlInsightThresholds.
        :type increase_in_io_in_pct: int

        :param increase_in_cpu_in_pct:
            The value to assign to the increase_in_cpu_in_pct property of this SqlInsightThresholds.
        :type increase_in_cpu_in_pct: int

        :param increase_in_inefficient_wait_in_pct:
            The value to assign to the increase_in_inefficient_wait_in_pct property of this SqlInsightThresholds.
        :type increase_in_inefficient_wait_in_pct: int

        :param improved_in_pct:
            The value to assign to the improved_in_pct property of this SqlInsightThresholds.
        :type improved_in_pct: int

        """
        self.swagger_types = {
            'degradation_in_pct': 'int',
            'variability': 'float',
            'inefficiency_in_pct': 'int',
            'increase_in_io_in_pct': 'int',
            'increase_in_cpu_in_pct': 'int',
            'increase_in_inefficient_wait_in_pct': 'int',
            'improved_in_pct': 'int'
        }

        self.attribute_map = {
            'degradation_in_pct': 'degradationInPct',
            'variability': 'variability',
            'inefficiency_in_pct': 'inefficiencyInPct',
            'increase_in_io_in_pct': 'increaseInIOInPct',
            'increase_in_cpu_in_pct': 'increaseInCPUInPct',
            'increase_in_inefficient_wait_in_pct': 'increaseInInefficientWaitInPct',
            'improved_in_pct': 'improvedInPct'
        }

        self._degradation_in_pct = None
        self._variability = None
        self._inefficiency_in_pct = None
        self._increase_in_io_in_pct = None
        self._increase_in_cpu_in_pct = None
        self._increase_in_inefficient_wait_in_pct = None
        self._improved_in_pct = None

    @property
    def degradation_in_pct(self):
        """
        **[Required]** Gets the degradation_in_pct of this SqlInsightThresholds.
        Degradation Percent Threshold is used to derive degrading SQLs.


        :return: The degradation_in_pct of this SqlInsightThresholds.
        :rtype: int
        """
        return self._degradation_in_pct

    @degradation_in_pct.setter
    def degradation_in_pct(self, degradation_in_pct):
        """
        Sets the degradation_in_pct of this SqlInsightThresholds.
        Degradation Percent Threshold is used to derive degrading SQLs.


        :param degradation_in_pct: The degradation_in_pct of this SqlInsightThresholds.
        :type: int
        """
        self._degradation_in_pct = degradation_in_pct

    @property
    def variability(self):
        """
        **[Required]** Gets the variability of this SqlInsightThresholds.
        Variability Percent Threshold is used to derive variant SQLs.


        :return: The variability of this SqlInsightThresholds.
        :rtype: float
        """
        return self._variability

    @variability.setter
    def variability(self, variability):
        """
        Sets the variability of this SqlInsightThresholds.
        Variability Percent Threshold is used to derive variant SQLs.


        :param variability: The variability of this SqlInsightThresholds.
        :type: float
        """
        self._variability = variability

    @property
    def inefficiency_in_pct(self):
        """
        **[Required]** Gets the inefficiency_in_pct of this SqlInsightThresholds.
        Inefficiency Percent Threshold is used to derive inefficient SQLs.


        :return: The inefficiency_in_pct of this SqlInsightThresholds.
        :rtype: int
        """
        return self._inefficiency_in_pct

    @inefficiency_in_pct.setter
    def inefficiency_in_pct(self, inefficiency_in_pct):
        """
        Sets the inefficiency_in_pct of this SqlInsightThresholds.
        Inefficiency Percent Threshold is used to derive inefficient SQLs.


        :param inefficiency_in_pct: The inefficiency_in_pct of this SqlInsightThresholds.
        :type: int
        """
        self._inefficiency_in_pct = inefficiency_in_pct

    @property
    def increase_in_io_in_pct(self):
        """
        **[Required]** Gets the increase_in_io_in_pct of this SqlInsightThresholds.
        PctIncreaseInIO is used for deriving insights for SQLs which are degrading or
        variant or inefficient. And these SQLs should also have increasing change in IO Time
        beyond threshold. Insights are derived using linear regression.


        :return: The increase_in_io_in_pct of this SqlInsightThresholds.
        :rtype: int
        """
        return self._increase_in_io_in_pct

    @increase_in_io_in_pct.setter
    def increase_in_io_in_pct(self, increase_in_io_in_pct):
        """
        Sets the increase_in_io_in_pct of this SqlInsightThresholds.
        PctIncreaseInIO is used for deriving insights for SQLs which are degrading or
        variant or inefficient. And these SQLs should also have increasing change in IO Time
        beyond threshold. Insights are derived using linear regression.


        :param increase_in_io_in_pct: The increase_in_io_in_pct of this SqlInsightThresholds.
        :type: int
        """
        self._increase_in_io_in_pct = increase_in_io_in_pct

    @property
    def increase_in_cpu_in_pct(self):
        """
        **[Required]** Gets the increase_in_cpu_in_pct of this SqlInsightThresholds.
        PctIncreaseInCPU is used for deriving insights for SQLs which are degrading or
        variant or inefficient. And these SQLs should also have increasing change in CPU Time
        beyond threshold. Insights are derived using linear regression.


        :return: The increase_in_cpu_in_pct of this SqlInsightThresholds.
        :rtype: int
        """
        return self._increase_in_cpu_in_pct

    @increase_in_cpu_in_pct.setter
    def increase_in_cpu_in_pct(self, increase_in_cpu_in_pct):
        """
        Sets the increase_in_cpu_in_pct of this SqlInsightThresholds.
        PctIncreaseInCPU is used for deriving insights for SQLs which are degrading or
        variant or inefficient. And these SQLs should also have increasing change in CPU Time
        beyond threshold. Insights are derived using linear regression.


        :param increase_in_cpu_in_pct: The increase_in_cpu_in_pct of this SqlInsightThresholds.
        :type: int
        """
        self._increase_in_cpu_in_pct = increase_in_cpu_in_pct

    @property
    def increase_in_inefficient_wait_in_pct(self):
        """
        **[Required]** Gets the increase_in_inefficient_wait_in_pct of this SqlInsightThresholds.
        PctIncreaseInIO is used for deriving insights for SQLs which are degrading or
        variant or inefficient. And these SQLs should also have increasing change in
        Other Wait Time beyond threshold. Insights are derived using linear regression.


        :return: The increase_in_inefficient_wait_in_pct of this SqlInsightThresholds.
        :rtype: int
        """
        return self._increase_in_inefficient_wait_in_pct

    @increase_in_inefficient_wait_in_pct.setter
    def increase_in_inefficient_wait_in_pct(self, increase_in_inefficient_wait_in_pct):
        """
        Sets the increase_in_inefficient_wait_in_pct of this SqlInsightThresholds.
        PctIncreaseInIO is used for deriving insights for SQLs which are degrading or
        variant or inefficient. And these SQLs should also have increasing change in
        Other Wait Time beyond threshold. Insights are derived using linear regression.


        :param increase_in_inefficient_wait_in_pct: The increase_in_inefficient_wait_in_pct of this SqlInsightThresholds.
        :type: int
        """
        self._increase_in_inefficient_wait_in_pct = increase_in_inefficient_wait_in_pct

    @property
    def improved_in_pct(self):
        """
        **[Required]** Gets the improved_in_pct of this SqlInsightThresholds.
        Improved Percent Threshold is used to derive improving SQLs.


        :return: The improved_in_pct of this SqlInsightThresholds.
        :rtype: int
        """
        return self._improved_in_pct

    @improved_in_pct.setter
    def improved_in_pct(self, improved_in_pct):
        """
        Sets the improved_in_pct of this SqlInsightThresholds.
        Improved Percent Threshold is used to derive improving SQLs.


        :param improved_in_pct: The improved_in_pct of this SqlInsightThresholds.
        :type: int
        """
        self._improved_in_pct = improved_in_pct

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataItem(object):
    """
    Simple object representing signal values at a certain point in time.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DataItem object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param timestamp:
            The value to assign to the timestamp property of this DataItem.
        :type timestamp: datetime

        :param values:
            The value to assign to the values property of this DataItem.
        :type values: list[float]

        """
        self.swagger_types = {
            'timestamp': 'datetime',
            'values': 'list[float]'
        }

        self.attribute_map = {
            'timestamp': 'timestamp',
            'values': 'values'
        }

        self._timestamp = None
        self._values = None

    @property
    def timestamp(self):
        """
        Gets the timestamp of this DataItem.
        Nullable string representing timestamp.


        :return: The timestamp of this DataItem.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this DataItem.
        Nullable string representing timestamp.


        :param timestamp: The timestamp of this DataItem.
        :type: datetime
        """
        self._timestamp = timestamp

    @property
    def values(self):
        """
        **[Required]** Gets the values of this DataItem.
        Array of double precision values.


        :return: The values of this DataItem.
        :rtype: list[float]
        """
        return self._values

    @values.setter
    def values(self, values):
        """
        Sets the values of this DataItem.
        Array of double precision values.


        :param values: The values of this DataItem.
        :type: list[float]
        """
        self._values = values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseObject(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Database objects to exclude from migration
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseObject object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param owner:
            The value to assign to the owner property of this DatabaseObject.
        :type owner: str

        :param object_name:
            The value to assign to the object_name property of this DatabaseObject.
        :type object_name: str

        """
        self.swagger_types = {
            'owner': 'str',
            'object_name': 'str'
        }

        self.attribute_map = {
            'owner': 'owner',
            'object_name': 'objectName'
        }

        self._owner = None
        self._object_name = None

    @property
    def owner(self):
        """
        **[Required]** Gets the owner of this DatabaseObject.
        Owner of the object (regular expression is allowed)


        :return: The owner of this DatabaseObject.
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this DatabaseObject.
        Owner of the object (regular expression is allowed)


        :param owner: The owner of this DatabaseObject.
        :type: str
        """
        self._owner = owner

    @property
    def object_name(self):
        """
        **[Required]** Gets the object_name of this DatabaseObject.
        Name of the object (regular expression is allowed)


        :return: The object_name of this DatabaseObject.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this DatabaseObject.
        Name of the object (regular expression is allowed)


        :param object_name: The object_name of this DatabaseObject.
        :type: str
        """
        self._object_name = object_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NetworkLoadBalancerSummary(object):
    """
    Network load balancer object to be used for list operations.
    """

    #: A constant which can be used with the lifecycle_state property of a NetworkLoadBalancerSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a NetworkLoadBalancerSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a NetworkLoadBalancerSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a NetworkLoadBalancerSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a NetworkLoadBalancerSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a NetworkLoadBalancerSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new NetworkLoadBalancerSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this NetworkLoadBalancerSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this NetworkLoadBalancerSummary.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this NetworkLoadBalancerSummary.
        :type display_name: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this NetworkLoadBalancerSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this NetworkLoadBalancerSummary.
        :type lifecycle_details: str

        :param time_created:
            The value to assign to the time_created property of this NetworkLoadBalancerSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this NetworkLoadBalancerSummary.
        :type time_updated: datetime

        :param ip_addresses:
            The value to assign to the ip_addresses property of this NetworkLoadBalancerSummary.
        :type ip_addresses: list[oci.network_load_balancer.models.IpAddress]

        :param is_private:
            The value to assign to the is_private property of this NetworkLoadBalancerSummary.
        :type is_private: bool

        :param is_preserve_source_destination:
            The value to assign to the is_preserve_source_destination property of this NetworkLoadBalancerSummary.
        :type is_preserve_source_destination: bool

        :param subnet_id:
            The value to assign to the subnet_id property of this NetworkLoadBalancerSummary.
        :type subnet_id: str

        :param network_security_group_ids:
            The value to assign to the network_security_group_ids property of this NetworkLoadBalancerSummary.
        :type network_security_group_ids: list[str]

        :param listeners:
            The value to assign to the listeners property of this NetworkLoadBalancerSummary.
        :type listeners: dict(str, Listener)

        :param backend_sets:
            The value to assign to the backend_sets property of this NetworkLoadBalancerSummary.
        :type backend_sets: dict(str, BackendSet)

        :param freeform_tags:
            The value to assign to the freeform_tags property of this NetworkLoadBalancerSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this NetworkLoadBalancerSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this NetworkLoadBalancerSummary.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'ip_addresses': 'list[IpAddress]',
            'is_private': 'bool',
            'is_preserve_source_destination': 'bool',
            'subnet_id': 'str',
            'network_security_group_ids': 'list[str]',
            'listeners': 'dict(str, Listener)',
            'backend_sets': 'dict(str, BackendSet)',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'ip_addresses': 'ipAddresses',
            'is_private': 'isPrivate',
            'is_preserve_source_destination': 'isPreserveSourceDestination',
            'subnet_id': 'subnetId',
            'network_security_group_ids': 'networkSecurityGroupIds',
            'listeners': 'listeners',
            'backend_sets': 'backendSets',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_created = None
        self._time_updated = None
        self._ip_addresses = None
        self._is_private = None
        self._is_preserve_source_destination = None
        self._subnet_id = None
        self._network_security_group_ids = None
        self._listeners = None
        self._backend_sets = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this NetworkLoadBalancerSummary.
        The `OCID`__ of the network load balancer.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this NetworkLoadBalancerSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this NetworkLoadBalancerSummary.
        The `OCID`__ of the network load balancer.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this NetworkLoadBalancerSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this NetworkLoadBalancerSummary.
        The `OCID`__ of the compartment containing the network load balancer.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this NetworkLoadBalancerSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this NetworkLoadBalancerSummary.
        The `OCID`__ of the compartment containing the network load balancer.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this NetworkLoadBalancerSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this NetworkLoadBalancerSummary.
        A user-friendly name, which does not have to be unique, and can be changed.

        Example: `example_load_balancer`


        :return: The display_name of this NetworkLoadBalancerSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this NetworkLoadBalancerSummary.
        A user-friendly name, which does not have to be unique, and can be changed.

        Example: `example_load_balancer`


        :param display_name: The display_name of this NetworkLoadBalancerSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this NetworkLoadBalancerSummary.
        The current state of the network load balancer.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this NetworkLoadBalancerSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this NetworkLoadBalancerSummary.
        The current state of the network load balancer.


        :param lifecycle_state: The lifecycle_state of this NetworkLoadBalancerSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this NetworkLoadBalancerSummary.
        A message describing the current state in more detail.
        For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecycle_details of this NetworkLoadBalancerSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this NetworkLoadBalancerSummary.
        A message describing the current state in more detail.
        For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecycle_details: The lifecycle_details of this NetworkLoadBalancerSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this NetworkLoadBalancerSummary.
        The date and time the network load balancer was created, in the format defined by RFC3339.

        Example: `2020-05-01T21:10:29.600Z`


        :return: The time_created of this NetworkLoadBalancerSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this NetworkLoadBalancerSummary.
        The date and time the network load balancer was created, in the format defined by RFC3339.

        Example: `2020-05-01T21:10:29.600Z`


        :param time_created: The time_created of this NetworkLoadBalancerSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this NetworkLoadBalancerSummary.
        The time the network load balancer was updated. An RFC3339 formatted date-time string.

        Example: `2020-05-01T22:10:29.600Z`


        :return: The time_updated of this NetworkLoadBalancerSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this NetworkLoadBalancerSummary.
        The time the network load balancer was updated. An RFC3339 formatted date-time string.

        Example: `2020-05-01T22:10:29.600Z`


        :param time_updated: The time_updated of this NetworkLoadBalancerSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def ip_addresses(self):
        """
        **[Required]** Gets the ip_addresses of this NetworkLoadBalancerSummary.
        An array of IP addresses.


        :return: The ip_addresses of this NetworkLoadBalancerSummary.
        :rtype: list[oci.network_load_balancer.models.IpAddress]
        """
        return self._ip_addresses

    @ip_addresses.setter
    def ip_addresses(self, ip_addresses):
        """
        Sets the ip_addresses of this NetworkLoadBalancerSummary.
        An array of IP addresses.


        :param ip_addresses: The ip_addresses of this NetworkLoadBalancerSummary.
        :type: list[oci.network_load_balancer.models.IpAddress]
        """
        self._ip_addresses = ip_addresses

    @property
    def is_private(self):
        """
        Gets the is_private of this NetworkLoadBalancerSummary.
        Whether the network load balancer has a virtual cloud network-local (private) IP address.

        If \"true\", then the service assigns a private IP address to the network load balancer.

        If \"false\", then the service assigns a public IP address to the network load balancer.

        A public network load balancer is accessible from the internet, depending the
        `security list rules`__ for your virtual cloudn network. For more information about public and
        private network load balancers,
        see `How Network Load Balancing Works`__.
        This value is true by default.

        Example: `true`

        __ https://docs.cloud.oracle.com/Content/network/Concepts/securitylists.htm
        __ https://docs.cloud.oracle.com/Content/Balance/Concepts/balanceoverview.htm#how-network-load-balancing-works


        :return: The is_private of this NetworkLoadBalancerSummary.
        :rtype: bool
        """
        return self._is_private

    @is_private.setter
    def is_private(self, is_private):
        """
        Sets the is_private of this NetworkLoadBalancerSummary.
        Whether the network load balancer has a virtual cloud network-local (private) IP address.

        If \"true\", then the service assigns a private IP address to the network load balancer.

        If \"false\", then the service assigns a public IP address to the network load balancer.

        A public network load balancer is accessible from the internet, depending the
        `security list rules`__ for your virtual cloudn network. For more information about public and
        private network load balancers,
        see `How Network Load Balancing Works`__.
        This value is true by default.

        Example: `true`

        __ https://docs.cloud.oracle.com/Content/network/Concepts/securitylists.htm
        __ https://docs.cloud.oracle.com/Content/Balance/Concepts/balanceoverview.htm#how-network-load-balancing-works


        :param is_private: The is_private of this NetworkLoadBalancerSummary.
        :type: bool
        """
        self._is_private = is_private

    @property
    def is_preserve_source_destination(self):
        """
        Gets the is_preserve_source_destination of this NetworkLoadBalancerSummary.
        When enabled, the skipSourceDestinationCheck parameter is automatically enabled on the load balancer VNIC.
        Packets are sent to the backend set without any changes to the source and destination IP.


        :return: The is_preserve_source_destination of this NetworkLoadBalancerSummary.
        :rtype: bool
        """
        return self._is_preserve_source_destination

    @is_preserve_source_destination.setter
    def is_preserve_source_destination(self, is_preserve_source_destination):
        """
        Sets the is_preserve_source_destination of this NetworkLoadBalancerSummary.
        When enabled, the skipSourceDestinationCheck parameter is automatically enabled on the load balancer VNIC.
        Packets are sent to the backend set without any changes to the source and destination IP.


        :param is_preserve_source_destination: The is_preserve_source_destination of this NetworkLoadBalancerSummary.
        :type: bool
        """
        self._is_preserve_source_destination = is_preserve_source_destination

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this NetworkLoadBalancerSummary.
        The subnet in which the network load balancer is spawned `OCIDs`__.\"

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this NetworkLoadBalancerSummary.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this NetworkLoadBalancerSummary.
        The subnet in which the network load balancer is spawned `OCIDs`__.\"

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this NetworkLoadBalancerSummary.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def network_security_group_ids(self):
        """
        Gets the network_security_group_ids of this NetworkLoadBalancerSummary.
        An array of network security groups `OCIDs`__ associated with the network load
        balancer.

        During the creation of the network load balancer, the service adds the new load balancer to the specified network security groups.

        The benefits of associating the network load balancer with network security groups include:

        *  Network security groups define network security rules to govern ingress and egress traffic for the network load balancer.

        *  The network security rules of other resources can reference the network security groups associated with the network load balancer
           to ensure access.

        Example: [\"ocid1.nsg.oc1.phx.unique_ID\"]

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The network_security_group_ids of this NetworkLoadBalancerSummary.
        :rtype: list[str]
        """
        return self._network_security_group_ids

    @network_security_group_ids.setter
    def network_security_group_ids(self, network_security_group_ids):
        """
        Sets the network_security_group_ids of this NetworkLoadBalancerSummary.
        An array of network security groups `OCIDs`__ associated with the network load
        balancer.

        During the creation of the network load balancer, the service adds the new load balancer to the specified network security groups.

        The benefits of associating the network load balancer with network security groups include:

        *  Network security groups define network security rules to govern ingress and egress traffic for the network load balancer.

        *  The network security rules of other resources can reference the network security groups associated with the network load balancer
           to ensure access.

        Example: [\"ocid1.nsg.oc1.phx.unique_ID\"]

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param network_security_group_ids: The network_security_group_ids of this NetworkLoadBalancerSummary.
        :type: list[str]
        """
        self._network_security_group_ids = network_security_group_ids

    @property
    def listeners(self):
        """
        Gets the listeners of this NetworkLoadBalancerSummary.
        Listeners associated with the network load balancer.


        :return: The listeners of this NetworkLoadBalancerSummary.
        :rtype: dict(str, Listener)
        """
        return self._listeners

    @listeners.setter
    def listeners(self, listeners):
        """
        Sets the listeners of this NetworkLoadBalancerSummary.
        Listeners associated with the network load balancer.


        :param listeners: The listeners of this NetworkLoadBalancerSummary.
        :type: dict(str, Listener)
        """
        self._listeners = listeners

    @property
    def backend_sets(self):
        """
        Gets the backend_sets of this NetworkLoadBalancerSummary.
        Backend sets associated with the network load balancer.


        :return: The backend_sets of this NetworkLoadBalancerSummary.
        :rtype: dict(str, BackendSet)
        """
        return self._backend_sets

    @backend_sets.setter
    def backend_sets(self, backend_sets):
        """
        Sets the backend_sets of this NetworkLoadBalancerSummary.
        Backend sets associated with the network load balancer.


        :param backend_sets: The backend_sets of this NetworkLoadBalancerSummary.
        :type: dict(str, BackendSet)
        """
        self._backend_sets = backend_sets

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this NetworkLoadBalancerSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this NetworkLoadBalancerSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this NetworkLoadBalancerSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this NetworkLoadBalancerSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this NetworkLoadBalancerSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this NetworkLoadBalancerSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this NetworkLoadBalancerSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this NetworkLoadBalancerSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this NetworkLoadBalancerSummary.
        Key-value pair representing system tags' keys and values scoped to a namespace.
        Example: `{\"bar-key\": \"value\"}`


        :return: The system_tags of this NetworkLoadBalancerSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this NetworkLoadBalancerSummary.
        Key-value pair representing system tags' keys and values scoped to a namespace.
        Example: `{\"bar-key\": \"value\"}`


        :param system_tags: The system_tags of this NetworkLoadBalancerSummary.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SoftwarePackageDependency(object):
    """
    A dependency for a software package
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SoftwarePackageDependency object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param dependency:
            The value to assign to the dependency property of this SoftwarePackageDependency.
        :type dependency: str

        :param dependency_type:
            The value to assign to the dependency_type property of this SoftwarePackageDependency.
        :type dependency_type: str

        :param dependency_modifier:
            The value to assign to the dependency_modifier property of this SoftwarePackageDependency.
        :type dependency_modifier: str

        """
        self.swagger_types = {
            'dependency': 'str',
            'dependency_type': 'str',
            'dependency_modifier': 'str'
        }

        self.attribute_map = {
            'dependency': 'dependency',
            'dependency_type': 'dependencyType',
            'dependency_modifier': 'dependencyModifier'
        }

        self._dependency = None
        self._dependency_type = None
        self._dependency_modifier = None

    @property
    def dependency(self):
        """
        Gets the dependency of this SoftwarePackageDependency.
        the software package's dependency


        :return: The dependency of this SoftwarePackageDependency.
        :rtype: str
        """
        return self._dependency

    @dependency.setter
    def dependency(self, dependency):
        """
        Sets the dependency of this SoftwarePackageDependency.
        the software package's dependency


        :param dependency: The dependency of this SoftwarePackageDependency.
        :type: str
        """
        self._dependency = dependency

    @property
    def dependency_type(self):
        """
        Gets the dependency_type of this SoftwarePackageDependency.
        the type of the dependency


        :return: The dependency_type of this SoftwarePackageDependency.
        :rtype: str
        """
        return self._dependency_type

    @dependency_type.setter
    def dependency_type(self, dependency_type):
        """
        Sets the dependency_type of this SoftwarePackageDependency.
        the type of the dependency


        :param dependency_type: The dependency_type of this SoftwarePackageDependency.
        :type: str
        """
        self._dependency_type = dependency_type

    @property
    def dependency_modifier(self):
        """
        Gets the dependency_modifier of this SoftwarePackageDependency.
        the modifier for the dependency


        :return: The dependency_modifier of this SoftwarePackageDependency.
        :rtype: str
        """
        return self._dependency_modifier

    @dependency_modifier.setter
    def dependency_modifier(self, dependency_modifier):
        """
        Sets the dependency_modifier of this SoftwarePackageDependency.
        the modifier for the dependency


        :param dependency_modifier: The dependency_modifier of this SoftwarePackageDependency.
        :type: str
        """
        self._dependency_modifier = dependency_modifier

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonitorResult(object):
    """
    The monitor result for a specific execution.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MonitorResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param result_type:
            The value to assign to the result_type property of this MonitorResult.
        :type result_type: str

        :param result_content_type:
            The value to assign to the result_content_type property of this MonitorResult.
        :type result_content_type: str

        :param result_data_set:
            The value to assign to the result_data_set property of this MonitorResult.
        :type result_data_set: list[oci.apm_synthetics.models.MonitorResultData]

        :param monitor_id:
            The value to assign to the monitor_id property of this MonitorResult.
        :type monitor_id: str

        :param vantage_point:
            The value to assign to the vantage_point property of this MonitorResult.
        :type vantage_point: str

        :param execution_time:
            The value to assign to the execution_time property of this MonitorResult.
        :type execution_time: str

        """
        self.swagger_types = {
            'result_type': 'str',
            'result_content_type': 'str',
            'result_data_set': 'list[MonitorResultData]',
            'monitor_id': 'str',
            'vantage_point': 'str',
            'execution_time': 'str'
        }

        self.attribute_map = {
            'result_type': 'resultType',
            'result_content_type': 'resultContentType',
            'result_data_set': 'resultDataSet',
            'monitor_id': 'monitorId',
            'vantage_point': 'vantagePoint',
            'execution_time': 'executionTime'
        }

        self._result_type = None
        self._result_content_type = None
        self._result_data_set = None
        self._monitor_id = None
        self._vantage_point = None
        self._execution_time = None

    @property
    def result_type(self):
        """
        Gets the result_type of this MonitorResult.
        Type of result.
        Example: HAR, Screenshot or Log.


        :return: The result_type of this MonitorResult.
        :rtype: str
        """
        return self._result_type

    @result_type.setter
    def result_type(self, result_type):
        """
        Sets the result_type of this MonitorResult.
        Type of result.
        Example: HAR, Screenshot or Log.


        :param result_type: The result_type of this MonitorResult.
        :type: str
        """
        self._result_type = result_type

    @property
    def result_content_type(self):
        """
        **[Required]** Gets the result_content_type of this MonitorResult.
        Type of result content.
        Example: Zip or Raw file.


        :return: The result_content_type of this MonitorResult.
        :rtype: str
        """
        return self._result_content_type

    @result_content_type.setter
    def result_content_type(self, result_content_type):
        """
        Sets the result_content_type of this MonitorResult.
        Type of result content.
        Example: Zip or Raw file.


        :param result_content_type: The result_content_type of this MonitorResult.
        :type: str
        """
        self._result_content_type = result_content_type

    @property
    def result_data_set(self):
        """
        Gets the result_data_set of this MonitorResult.
        Monitor result data set.


        :return: The result_data_set of this MonitorResult.
        :rtype: list[oci.apm_synthetics.models.MonitorResultData]
        """
        return self._result_data_set

    @result_data_set.setter
    def result_data_set(self, result_data_set):
        """
        Sets the result_data_set of this MonitorResult.
        Monitor result data set.


        :param result_data_set: The result_data_set of this MonitorResult.
        :type: list[oci.apm_synthetics.models.MonitorResultData]
        """
        self._result_data_set = result_data_set

    @property
    def monitor_id(self):
        """
        Gets the monitor_id of this MonitorResult.
        The `OCID`__ of the monitor.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The monitor_id of this MonitorResult.
        :rtype: str
        """
        return self._monitor_id

    @monitor_id.setter
    def monitor_id(self, monitor_id):
        """
        Sets the monitor_id of this MonitorResult.
        The `OCID`__ of the monitor.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param monitor_id: The monitor_id of this MonitorResult.
        :type: str
        """
        self._monitor_id = monitor_id

    @property
    def vantage_point(self):
        """
        Gets the vantage_point of this MonitorResult.
        The name of the vantage point.


        :return: The vantage_point of this MonitorResult.
        :rtype: str
        """
        return self._vantage_point

    @vantage_point.setter
    def vantage_point(self, vantage_point):
        """
        Sets the vantage_point of this MonitorResult.
        The name of the vantage point.


        :param vantage_point: The vantage_point of this MonitorResult.
        :type: str
        """
        self._vantage_point = vantage_point

    @property
    def execution_time(self):
        """
        Gets the execution_time of this MonitorResult.
        The specific point of time when the result of an execution is collected.


        :return: The execution_time of this MonitorResult.
        :rtype: str
        """
        return self._execution_time

    @execution_time.setter
    def execution_time(self, execution_time):
        """
        Sets the execution_time of this MonitorResult.
        The specific point of time when the result of an execution is collected.


        :param execution_time: The execution_time of this MonitorResult.
        :type: str
        """
        self._execution_time = execution_time

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .action import Action
from .auto_scaling_configuration import AutoScalingConfiguration
from .auto_scaling_configuration_summary import AutoScalingConfigurationSummary
from .auto_scaling_policy import AutoScalingPolicy
from .auto_scaling_policy_summary import AutoScalingPolicySummary
from .capacity import Capacity
from .change_auto_scaling_compartment_details import ChangeAutoScalingCompartmentDetails
from .condition import Condition
from .create_auto_scaling_configuration_details import CreateAutoScalingConfigurationDetails
from .create_auto_scaling_policy_details import CreateAutoScalingPolicyDetails
from .create_condition_details import CreateConditionDetails
from .create_scheduled_policy_details import CreateScheduledPolicyDetails
from .create_threshold_policy_details import CreateThresholdPolicyDetails
from .cron_execution_schedule import CronExecutionSchedule
from .execution_schedule import ExecutionSchedule
from .instance_pool_resource import InstancePoolResource
from .metric import Metric
from .resource import Resource
from .resource_action import ResourceAction
from .resource_power_action import ResourcePowerAction
from .scheduled_policy import ScheduledPolicy
from .threshold import Threshold
from .threshold_policy import ThresholdPolicy
from .update_auto_scaling_configuration_details import UpdateAutoScalingConfigurationDetails
from .update_auto_scaling_policy_details import UpdateAutoScalingPolicyDetails
from .update_condition_details import UpdateConditionDetails
from .update_scheduled_policy_details import UpdateScheduledPolicyDetails
from .update_threshold_policy_details import UpdateThresholdPolicyDetails

# Maps type names to classes for autoscaling services.
autoscaling_type_mapping = {
    "Action": Action,
    "AutoScalingConfiguration": AutoScalingConfiguration,
    "AutoScalingConfigurationSummary": AutoScalingConfigurationSummary,
    "AutoScalingPolicy": AutoScalingPolicy,
    "AutoScalingPolicySummary": AutoScalingPolicySummary,
    "Capacity": Capacity,
    "ChangeAutoScalingCompartmentDetails": ChangeAutoScalingCompartmentDetails,
    "Condition": Condition,
    "CreateAutoScalingConfigurationDetails": CreateAutoScalingConfigurationDetails,
    "CreateAutoScalingPolicyDetails": CreateAutoScalingPolicyDetails,
    "CreateConditionDetails": CreateConditionDetails,
    "CreateScheduledPolicyDetails": CreateScheduledPolicyDetails,
    "CreateThresholdPolicyDetails": CreateThresholdPolicyDetails,
    "CronExecutionSchedule": CronExecutionSchedule,
    "ExecutionSchedule": ExecutionSchedule,
    "InstancePoolResource": InstancePoolResource,
    "Metric": Metric,
    "Resource": Resource,
    "ResourceAction": ResourceAction,
    "ResourcePowerAction": ResourcePowerAction,
    "ScheduledPolicy": ScheduledPolicy,
    "Threshold": Threshold,
    "ThresholdPolicy": ThresholdPolicy,
    "UpdateAutoScalingConfigurationDetails": UpdateAutoScalingConfigurationDetails,
    "UpdateAutoScalingPolicyDetails": UpdateAutoScalingPolicyDetails,
    "UpdateConditionDetails": UpdateConditionDetails,
    "UpdateScheduledPolicyDetails": UpdateScheduledPolicyDetails,
    "UpdateThresholdPolicyDetails": UpdateThresholdPolicyDetails
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LaunchDbSystemBase(object):
    """
    Parameters for provisioning a bare metal, virtual machine, or Exadata DB system.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the source property of a LaunchDbSystemBase.
    #: This constant has a value of "NONE"
    SOURCE_NONE = "NONE"

    #: A constant which can be used with the source property of a LaunchDbSystemBase.
    #: This constant has a value of "DB_BACKUP"
    SOURCE_DB_BACKUP = "DB_BACKUP"

    #: A constant which can be used with the source property of a LaunchDbSystemBase.
    #: This constant has a value of "DATABASE"
    SOURCE_DATABASE = "DATABASE"

    #: A constant which can be used with the source property of a LaunchDbSystemBase.
    #: This constant has a value of "DB_SYSTEM"
    SOURCE_DB_SYSTEM = "DB_SYSTEM"

    def __init__(self, **kwargs):
        """
        Initializes a new LaunchDbSystemBase object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.database.models.LaunchDbSystemDetails`
        * :class:`~oci.database.models.LaunchDbSystemFromDbSystemDetails`
        * :class:`~oci.database.models.LaunchDbSystemFromDatabaseDetails`
        * :class:`~oci.database.models.LaunchDbSystemFromBackupDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this LaunchDbSystemBase.
        :type compartment_id: str

        :param fault_domains:
            The value to assign to the fault_domains property of this LaunchDbSystemBase.
        :type fault_domains: list[str]

        :param display_name:
            The value to assign to the display_name property of this LaunchDbSystemBase.
        :type display_name: str

        :param availability_domain:
            The value to assign to the availability_domain property of this LaunchDbSystemBase.
        :type availability_domain: str

        :param subnet_id:
            The value to assign to the subnet_id property of this LaunchDbSystemBase.
        :type subnet_id: str

        :param backup_subnet_id:
            The value to assign to the backup_subnet_id property of this LaunchDbSystemBase.
        :type backup_subnet_id: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this LaunchDbSystemBase.
        :type nsg_ids: list[str]

        :param backup_network_nsg_ids:
            The value to assign to the backup_network_nsg_ids property of this LaunchDbSystemBase.
        :type backup_network_nsg_ids: list[str]

        :param shape:
            The value to assign to the shape property of this LaunchDbSystemBase.
        :type shape: str

        :param time_zone:
            The value to assign to the time_zone property of this LaunchDbSystemBase.
        :type time_zone: str

        :param db_system_options:
            The value to assign to the db_system_options property of this LaunchDbSystemBase.
        :type db_system_options: oci.database.models.DbSystemOptions

        :param sparse_diskgroup:
            The value to assign to the sparse_diskgroup property of this LaunchDbSystemBase.
        :type sparse_diskgroup: bool

        :param ssh_public_keys:
            The value to assign to the ssh_public_keys property of this LaunchDbSystemBase.
        :type ssh_public_keys: list[str]

        :param hostname:
            The value to assign to the hostname property of this LaunchDbSystemBase.
        :type hostname: str

        :param domain:
            The value to assign to the domain property of this LaunchDbSystemBase.
        :type domain: str

        :param cpu_core_count:
            The value to assign to the cpu_core_count property of this LaunchDbSystemBase.
        :type cpu_core_count: int

        :param cluster_name:
            The value to assign to the cluster_name property of this LaunchDbSystemBase.
        :type cluster_name: str

        :param data_storage_percentage:
            The value to assign to the data_storage_percentage property of this LaunchDbSystemBase.
        :type data_storage_percentage: int

        :param initial_data_storage_size_in_gb:
            The value to assign to the initial_data_storage_size_in_gb property of this LaunchDbSystemBase.
        :type initial_data_storage_size_in_gb: int

        :param kms_key_id:
            The value to assign to the kms_key_id property of this LaunchDbSystemBase.
        :type kms_key_id: str

        :param kms_key_version_id:
            The value to assign to the kms_key_version_id property of this LaunchDbSystemBase.
        :type kms_key_version_id: str

        :param node_count:
            The value to assign to the node_count property of this LaunchDbSystemBase.
        :type node_count: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this LaunchDbSystemBase.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this LaunchDbSystemBase.
        :type defined_tags: dict(str, dict(str, object))

        :param source:
            The value to assign to the source property of this LaunchDbSystemBase.
            Allowed values for this property are: "NONE", "DB_BACKUP", "DATABASE", "DB_SYSTEM"
        :type source: str

        :param private_ip:
            The value to assign to the private_ip property of this LaunchDbSystemBase.
        :type private_ip: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'fault_domains': 'list[str]',
            'display_name': 'str',
            'availability_domain': 'str',
            'subnet_id': 'str',
            'backup_subnet_id': 'str',
            'nsg_ids': 'list[str]',
            'backup_network_nsg_ids': 'list[str]',
            'shape': 'str',
            'time_zone': 'str',
            'db_system_options': 'DbSystemOptions',
            'sparse_diskgroup': 'bool',
            'ssh_public_keys': 'list[str]',
            'hostname': 'str',
            'domain': 'str',
            'cpu_core_count': 'int',
            'cluster_name': 'str',
            'data_storage_percentage': 'int',
            'initial_data_storage_size_in_gb': 'int',
            'kms_key_id': 'str',
            'kms_key_version_id': 'str',
            'node_count': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'source': 'str',
            'private_ip': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'fault_domains': 'faultDomains',
            'display_name': 'displayName',
            'availability_domain': 'availabilityDomain',
            'subnet_id': 'subnetId',
            'backup_subnet_id': 'backupSubnetId',
            'nsg_ids': 'nsgIds',
            'backup_network_nsg_ids': 'backupNetworkNsgIds',
            'shape': 'shape',
            'time_zone': 'timeZone',
            'db_system_options': 'dbSystemOptions',
            'sparse_diskgroup': 'sparseDiskgroup',
            'ssh_public_keys': 'sshPublicKeys',
            'hostname': 'hostname',
            'domain': 'domain',
            'cpu_core_count': 'cpuCoreCount',
            'cluster_name': 'clusterName',
            'data_storage_percentage': 'dataStoragePercentage',
            'initial_data_storage_size_in_gb': 'initialDataStorageSizeInGB',
            'kms_key_id': 'kmsKeyId',
            'kms_key_version_id': 'kmsKeyVersionId',
            'node_count': 'nodeCount',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'source': 'source',
            'private_ip': 'privateIp'
        }

        self._compartment_id = None
        self._fault_domains = None
        self._display_name = None
        self._availability_domain = None
        self._subnet_id = None
        self._backup_subnet_id = None
        self._nsg_ids = None
        self._backup_network_nsg_ids = None
        self._shape = None
        self._time_zone = None
        self._db_system_options = None
        self._sparse_diskgroup = None
        self._ssh_public_keys = None
        self._hostname = None
        self._domain = None
        self._cpu_core_count = None
        self._cluster_name = None
        self._data_storage_percentage = None
        self._initial_data_storage_size_in_gb = None
        self._kms_key_id = None
        self._kms_key_version_id = None
        self._node_count = None
        self._freeform_tags = None
        self._defined_tags = None
        self._source = None
        self._private_ip = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['source']

        if type == 'NONE':
            return 'LaunchDbSystemDetails'

        if type == 'DB_SYSTEM':
            return 'LaunchDbSystemFromDbSystemDetails'

        if type == 'DATABASE':
            return 'LaunchDbSystemFromDatabaseDetails'

        if type == 'DB_BACKUP':
            return 'LaunchDbSystemFromBackupDetails'
        else:
            return 'LaunchDbSystemBase'

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this LaunchDbSystemBase.
        The `OCID`__ of the compartment the DB system  belongs in.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this LaunchDbSystemBase.
        The `OCID`__ of the compartment the DB system  belongs in.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this LaunchDbSystemBase.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def fault_domains(self):
        """
        Gets the fault_domains of this LaunchDbSystemBase.
        A Fault Domain is a grouping of hardware and infrastructure within an availability domain.
        Fault Domains let you distribute your instances so that they are not on the same physical
        hardware within a single availability domain. A hardware failure or maintenance
        that affects one Fault Domain does not affect DB systems in other Fault Domains.

        If you do not specify the Fault Domain, the system selects one for you. To change the Fault
        Domain for a DB system, terminate it and launch a new DB system in the preferred Fault Domain.

        If the node count is greater than 1, you can specify which Fault Domains these nodes will be distributed into.
        The system assigns your nodes automatically to the Fault Domains you specify so that
        no Fault Domain contains more than one node.

        To get a list of Fault Domains, use the
        :func:`list_fault_domains` operation in the
        Identity and Access Management Service API.

        Example: `FAULT-DOMAIN-1`


        :return: The fault_domains of this LaunchDbSystemBase.
        :rtype: list[str]
        """
        return self._fault_domains

    @fault_domains.setter
    def fault_domains(self, fault_domains):
        """
        Sets the fault_domains of this LaunchDbSystemBase.
        A Fault Domain is a grouping of hardware and infrastructure within an availability domain.
        Fault Domains let you distribute your instances so that they are not on the same physical
        hardware within a single availability domain. A hardware failure or maintenance
        that affects one Fault Domain does not affect DB systems in other Fault Domains.

        If you do not specify the Fault Domain, the system selects one for you. To change the Fault
        Domain for a DB system, terminate it and launch a new DB system in the preferred Fault Domain.

        If the node count is greater than 1, you can specify which Fault Domains these nodes will be distributed into.
        The system assigns your nodes automatically to the Fault Domains you specify so that
        no Fault Domain contains more than one node.

        To get a list of Fault Domains, use the
        :func:`list_fault_domains` operation in the
        Identity and Access Management Service API.

        Example: `FAULT-DOMAIN-1`


        :param fault_domains: The fault_domains of this LaunchDbSystemBase.
        :type: list[str]
        """
        self._fault_domains = fault_domains

    @property
    def display_name(self):
        """
        Gets the display_name of this LaunchDbSystemBase.
        The user-friendly name for the DB system. The name does not have to be unique.


        :return: The display_name of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this LaunchDbSystemBase.
        The user-friendly name for the DB system. The name does not have to be unique.


        :param display_name: The display_name of this LaunchDbSystemBase.
        :type: str
        """
        self._display_name = display_name

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this LaunchDbSystemBase.
        The availability domain where the DB system is located.


        :return: The availability_domain of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this LaunchDbSystemBase.
        The availability domain where the DB system is located.


        :param availability_domain: The availability_domain of this LaunchDbSystemBase.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this LaunchDbSystemBase.
        The `OCID`__ of the subnet the DB system is associated with.

        **Subnet Restrictions:**
        - For bare metal DB systems and for single node virtual machine DB systems, do not use a subnet that overlaps with 192.168.16.16/28.
        - For Exadata and virtual machine 2-node RAC DB systems, do not use a subnet that overlaps with 192.168.128.0/20.

        These subnets are used by the Oracle Clusterware private interconnect on the database instance.
        Specifying an overlapping subnet will cause the private interconnect to malfunction.
        This restriction applies to both the client subnet and the backup subnet.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this LaunchDbSystemBase.
        The `OCID`__ of the subnet the DB system is associated with.

        **Subnet Restrictions:**
        - For bare metal DB systems and for single node virtual machine DB systems, do not use a subnet that overlaps with 192.168.16.16/28.
        - For Exadata and virtual machine 2-node RAC DB systems, do not use a subnet that overlaps with 192.168.128.0/20.

        These subnets are used by the Oracle Clusterware private interconnect on the database instance.
        Specifying an overlapping subnet will cause the private interconnect to malfunction.
        This restriction applies to both the client subnet and the backup subnet.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this LaunchDbSystemBase.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def backup_subnet_id(self):
        """
        Gets the backup_subnet_id of this LaunchDbSystemBase.
        The `OCID`__ of the backup network subnet the DB system is associated with. Applicable only to Exadata DB systems.

        **Subnet Restrictions:** See the subnet restrictions information for **subnetId**.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The backup_subnet_id of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._backup_subnet_id

    @backup_subnet_id.setter
    def backup_subnet_id(self, backup_subnet_id):
        """
        Sets the backup_subnet_id of this LaunchDbSystemBase.
        The `OCID`__ of the backup network subnet the DB system is associated with. Applicable only to Exadata DB systems.

        **Subnet Restrictions:** See the subnet restrictions information for **subnetId**.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param backup_subnet_id: The backup_subnet_id of this LaunchDbSystemBase.
        :type: str
        """
        self._backup_subnet_id = backup_subnet_id

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this LaunchDbSystemBase.
        A list of the `OCIDs`__ of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :return: The nsg_ids of this LaunchDbSystemBase.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this LaunchDbSystemBase.
        A list of the `OCIDs`__ of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :param nsg_ids: The nsg_ids of this LaunchDbSystemBase.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def backup_network_nsg_ids(self):
        """
        Gets the backup_network_nsg_ids of this LaunchDbSystemBase.
        A list of the `OCIDs`__ of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__. Applicable only to Exadata systems.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :return: The backup_network_nsg_ids of this LaunchDbSystemBase.
        :rtype: list[str]
        """
        return self._backup_network_nsg_ids

    @backup_network_nsg_ids.setter
    def backup_network_nsg_ids(self, backup_network_nsg_ids):
        """
        Sets the backup_network_nsg_ids of this LaunchDbSystemBase.
        A list of the `OCIDs`__ of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__. Applicable only to Exadata systems.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :param backup_network_nsg_ids: The backup_network_nsg_ids of this LaunchDbSystemBase.
        :type: list[str]
        """
        self._backup_network_nsg_ids = backup_network_nsg_ids

    @property
    def shape(self):
        """
        **[Required]** Gets the shape of this LaunchDbSystemBase.
        The shape of the DB system. The shape determines resources allocated to the DB system.
        - For virtual machine shapes, the number of CPU cores and memory
        - For bare metal and Exadata shapes, the number of CPU cores, memory, and storage

        To get a list of shapes, use the :func:`list_db_system_shapes` operation.


        :return: The shape of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this LaunchDbSystemBase.
        The shape of the DB system. The shape determines resources allocated to the DB system.
        - For virtual machine shapes, the number of CPU cores and memory
        - For bare metal and Exadata shapes, the number of CPU cores, memory, and storage

        To get a list of shapes, use the :func:`list_db_system_shapes` operation.


        :param shape: The shape of this LaunchDbSystemBase.
        :type: str
        """
        self._shape = shape

    @property
    def time_zone(self):
        """
        Gets the time_zone of this LaunchDbSystemBase.
        The time zone to use for the DB system. For details, see `DB System Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :return: The time_zone of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this LaunchDbSystemBase.
        The time zone to use for the DB system. For details, see `DB System Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :param time_zone: The time_zone of this LaunchDbSystemBase.
        :type: str
        """
        self._time_zone = time_zone

    @property
    def db_system_options(self):
        """
        Gets the db_system_options of this LaunchDbSystemBase.

        :return: The db_system_options of this LaunchDbSystemBase.
        :rtype: oci.database.models.DbSystemOptions
        """
        return self._db_system_options

    @db_system_options.setter
    def db_system_options(self, db_system_options):
        """
        Sets the db_system_options of this LaunchDbSystemBase.

        :param db_system_options: The db_system_options of this LaunchDbSystemBase.
        :type: oci.database.models.DbSystemOptions
        """
        self._db_system_options = db_system_options

    @property
    def sparse_diskgroup(self):
        """
        Gets the sparse_diskgroup of this LaunchDbSystemBase.
        If true, Sparse Diskgroup is configured for Exadata dbsystem. If False, Sparse diskgroup is not configured.


        :return: The sparse_diskgroup of this LaunchDbSystemBase.
        :rtype: bool
        """
        return self._sparse_diskgroup

    @sparse_diskgroup.setter
    def sparse_diskgroup(self, sparse_diskgroup):
        """
        Sets the sparse_diskgroup of this LaunchDbSystemBase.
        If true, Sparse Diskgroup is configured for Exadata dbsystem. If False, Sparse diskgroup is not configured.


        :param sparse_diskgroup: The sparse_diskgroup of this LaunchDbSystemBase.
        :type: bool
        """
        self._sparse_diskgroup = sparse_diskgroup

    @property
    def ssh_public_keys(self):
        """
        **[Required]** Gets the ssh_public_keys of this LaunchDbSystemBase.
        The public key portion of the key pair to use for SSH access to the DB system. Multiple public keys can be provided. The length of the combined keys cannot exceed 40,000 characters.


        :return: The ssh_public_keys of this LaunchDbSystemBase.
        :rtype: list[str]
        """
        return self._ssh_public_keys

    @ssh_public_keys.setter
    def ssh_public_keys(self, ssh_public_keys):
        """
        Sets the ssh_public_keys of this LaunchDbSystemBase.
        The public key portion of the key pair to use for SSH access to the DB system. Multiple public keys can be provided. The length of the combined keys cannot exceed 40,000 characters.


        :param ssh_public_keys: The ssh_public_keys of this LaunchDbSystemBase.
        :type: list[str]
        """
        self._ssh_public_keys = ssh_public_keys

    @property
    def hostname(self):
        """
        **[Required]** Gets the hostname of this LaunchDbSystemBase.
        The hostname for the DB system. The hostname must begin with an alphabetic character, and
        can contain alphanumeric characters and hyphens (-). The maximum length of the hostname is 16 characters for bare metal and virtual machine DB systems, and 12 characters for Exadata DB systems.

        The maximum length of the combined hostname and domain is 63 characters.

        **Note:** The hostname must be unique within the subnet. If it is not unique,
        the DB system will fail to provision.


        :return: The hostname of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """
        Sets the hostname of this LaunchDbSystemBase.
        The hostname for the DB system. The hostname must begin with an alphabetic character, and
        can contain alphanumeric characters and hyphens (-). The maximum length of the hostname is 16 characters for bare metal and virtual machine DB systems, and 12 characters for Exadata DB systems.

        The maximum length of the combined hostname and domain is 63 characters.

        **Note:** The hostname must be unique within the subnet. If it is not unique,
        the DB system will fail to provision.


        :param hostname: The hostname of this LaunchDbSystemBase.
        :type: str
        """
        self._hostname = hostname

    @property
    def domain(self):
        """
        Gets the domain of this LaunchDbSystemBase.
        A domain name used for the DB system. If the Oracle-provided Internet and VCN
        Resolver is enabled for the specified subnet, the domain name for the subnet is used
        (do not provide one). Otherwise, provide a valid DNS domain name. Hyphens (-) are not permitted.


        :return: The domain of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this LaunchDbSystemBase.
        A domain name used for the DB system. If the Oracle-provided Internet and VCN
        Resolver is enabled for the specified subnet, the domain name for the subnet is used
        (do not provide one). Otherwise, provide a valid DNS domain name. Hyphens (-) are not permitted.


        :param domain: The domain of this LaunchDbSystemBase.
        :type: str
        """
        self._domain = domain

    @property
    def cpu_core_count(self):
        """
        **[Required]** Gets the cpu_core_count of this LaunchDbSystemBase.
        The number of CPU cores to enable for a bare metal or Exadata DB system. The valid values depend on the specified shape:

        - BM.DenseIO1.36 - Specify a multiple of 2, from 2 to 36.
        - BM.DenseIO2.52 - Specify a multiple of 2, from 2 to 52.
        - Exadata.Base.48 - Specify a multiple of 2, from 0 to 48.
        - Exadata.Quarter1.84 - Specify a multiple of 2, from 22 to 84.
        - Exadata.Half1.168 - Specify a multiple of 4, from 44 to 168.
        - Exadata.Full1.336 - Specify a multiple of 8, from 88 to 336.
        - Exadata.Quarter2.92 - Specify a multiple of 2, from 0 to 92.
        - Exadata.Half2.184 - Specify a multiple of 4, from 0 to 184.
        - Exadata.Full2.368 - Specify a multiple of 8, from 0 to 368.

        This parameter is not used for virtual machine DB systems because virtual machine DB systems have a set number of cores for each shape.
        For information about the number of cores for a virtual machine DB system shape, see `Virtual Machine DB Systems`__

        __ https://docs.cloud.oracle.com/Content/Database/Concepts/overview.htm#virtualmachine


        :return: The cpu_core_count of this LaunchDbSystemBase.
        :rtype: int
        """
        return self._cpu_core_count

    @cpu_core_count.setter
    def cpu_core_count(self, cpu_core_count):
        """
        Sets the cpu_core_count of this LaunchDbSystemBase.
        The number of CPU cores to enable for a bare metal or Exadata DB system. The valid values depend on the specified shape:

        - BM.DenseIO1.36 - Specify a multiple of 2, from 2 to 36.
        - BM.DenseIO2.52 - Specify a multiple of 2, from 2 to 52.
        - Exadata.Base.48 - Specify a multiple of 2, from 0 to 48.
        - Exadata.Quarter1.84 - Specify a multiple of 2, from 22 to 84.
        - Exadata.Half1.168 - Specify a multiple of 4, from 44 to 168.
        - Exadata.Full1.336 - Specify a multiple of 8, from 88 to 336.
        - Exadata.Quarter2.92 - Specify a multiple of 2, from 0 to 92.
        - Exadata.Half2.184 - Specify a multiple of 4, from 0 to 184.
        - Exadata.Full2.368 - Specify a multiple of 8, from 0 to 368.

        This parameter is not used for virtual machine DB systems because virtual machine DB systems have a set number of cores for each shape.
        For information about the number of cores for a virtual machine DB system shape, see `Virtual Machine DB Systems`__

        __ https://docs.cloud.oracle.com/Content/Database/Concepts/overview.htm#virtualmachine


        :param cpu_core_count: The cpu_core_count of this LaunchDbSystemBase.
        :type: int
        """
        self._cpu_core_count = cpu_core_count

    @property
    def cluster_name(self):
        """
        Gets the cluster_name of this LaunchDbSystemBase.
        The cluster name for Exadata and 2-node RAC virtual machine DB systems. The cluster name must begin with an alphabetic character, and may contain hyphens (-). Underscores (_) are not permitted. The cluster name can be no longer than 11 characters and is not case sensitive.


        :return: The cluster_name of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._cluster_name

    @cluster_name.setter
    def cluster_name(self, cluster_name):
        """
        Sets the cluster_name of this LaunchDbSystemBase.
        The cluster name for Exadata and 2-node RAC virtual machine DB systems. The cluster name must begin with an alphabetic character, and may contain hyphens (-). Underscores (_) are not permitted. The cluster name can be no longer than 11 characters and is not case sensitive.


        :param cluster_name: The cluster_name of this LaunchDbSystemBase.
        :type: str
        """
        self._cluster_name = cluster_name

    @property
    def data_storage_percentage(self):
        """
        Gets the data_storage_percentage of this LaunchDbSystemBase.
        The percentage assigned to DATA storage (user data and database files).
        The remaining percentage is assigned to RECO storage (database redo logs, archive logs, and recovery manager backups).
        Specify 80 or 40. The default is 80 percent assigned to DATA storage. Not applicable for virtual machine DB systems.


        :return: The data_storage_percentage of this LaunchDbSystemBase.
        :rtype: int
        """
        return self._data_storage_percentage

    @data_storage_percentage.setter
    def data_storage_percentage(self, data_storage_percentage):
        """
        Sets the data_storage_percentage of this LaunchDbSystemBase.
        The percentage assigned to DATA storage (user data and database files).
        The remaining percentage is assigned to RECO storage (database redo logs, archive logs, and recovery manager backups).
        Specify 80 or 40. The default is 80 percent assigned to DATA storage. Not applicable for virtual machine DB systems.


        :param data_storage_percentage: The data_storage_percentage of this LaunchDbSystemBase.
        :type: int
        """
        self._data_storage_percentage = data_storage_percentage

    @property
    def initial_data_storage_size_in_gb(self):
        """
        Gets the initial_data_storage_size_in_gb of this LaunchDbSystemBase.
        Size (in GB) of the initial data volume that will be created and attached to a virtual machine DB system. You can scale up storage after provisioning, as needed. Note that the total storage size attached will be more than the amount you specify to allow for REDO/RECO space and software volume.


        :return: The initial_data_storage_size_in_gb of this LaunchDbSystemBase.
        :rtype: int
        """
        return self._initial_data_storage_size_in_gb

    @initial_data_storage_size_in_gb.setter
    def initial_data_storage_size_in_gb(self, initial_data_storage_size_in_gb):
        """
        Sets the initial_data_storage_size_in_gb of this LaunchDbSystemBase.
        Size (in GB) of the initial data volume that will be created and attached to a virtual machine DB system. You can scale up storage after provisioning, as needed. Note that the total storage size attached will be more than the amount you specify to allow for REDO/RECO space and software volume.


        :param initial_data_storage_size_in_gb: The initial_data_storage_size_in_gb of this LaunchDbSystemBase.
        :type: int
        """
        self._initial_data_storage_size_in_gb = initial_data_storage_size_in_gb

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this LaunchDbSystemBase.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :return: The kms_key_id of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this LaunchDbSystemBase.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :param kms_key_id: The kms_key_id of this LaunchDbSystemBase.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def kms_key_version_id(self):
        """
        Gets the kms_key_version_id of this LaunchDbSystemBase.
        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.


        :return: The kms_key_version_id of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._kms_key_version_id

    @kms_key_version_id.setter
    def kms_key_version_id(self, kms_key_version_id):
        """
        Sets the kms_key_version_id of this LaunchDbSystemBase.
        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.


        :param kms_key_version_id: The kms_key_version_id of this LaunchDbSystemBase.
        :type: str
        """
        self._kms_key_version_id = kms_key_version_id

    @property
    def node_count(self):
        """
        Gets the node_count of this LaunchDbSystemBase.
        The number of nodes to launch for a 2-node RAC virtual machine DB system. Specify either 1 or 2.


        :return: The node_count of this LaunchDbSystemBase.
        :rtype: int
        """
        return self._node_count

    @node_count.setter
    def node_count(self, node_count):
        """
        Sets the node_count of this LaunchDbSystemBase.
        The number of nodes to launch for a 2-node RAC virtual machine DB system. Specify either 1 or 2.


        :param node_count: The node_count of this LaunchDbSystemBase.
        :type: int
        """
        self._node_count = node_count

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this LaunchDbSystemBase.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this LaunchDbSystemBase.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this LaunchDbSystemBase.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this LaunchDbSystemBase.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this LaunchDbSystemBase.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this LaunchDbSystemBase.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this LaunchDbSystemBase.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this LaunchDbSystemBase.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def source(self):
        """
        Gets the source of this LaunchDbSystemBase.
        The source of the database:
        Use `NONE` for creating a new database. Use `DB_BACKUP` for creating a new database by restoring from a backup. Use `DATABASE` for creating
        a new database from an existing database, including archive redo log data. The default is `NONE`.

        Allowed values for this property are: "NONE", "DB_BACKUP", "DATABASE", "DB_SYSTEM"


        :return: The source of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this LaunchDbSystemBase.
        The source of the database:
        Use `NONE` for creating a new database. Use `DB_BACKUP` for creating a new database by restoring from a backup. Use `DATABASE` for creating
        a new database from an existing database, including archive redo log data. The default is `NONE`.


        :param source: The source of this LaunchDbSystemBase.
        :type: str
        """
        allowed_values = ["NONE", "DB_BACKUP", "DATABASE", "DB_SYSTEM"]
        if not value_allowed_none_or_none_sentinel(source, allowed_values):
            raise ValueError(
                "Invalid value for `source`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._source = source

    @property
    def private_ip(self):
        """
        Gets the private_ip of this LaunchDbSystemBase.
        A private IP address of your choice. Must be an available IP address within the subnet's CIDR.
        If you don't specify a value, Oracle automatically assigns a private IP address from the subnet.


        :return: The private_ip of this LaunchDbSystemBase.
        :rtype: str
        """
        return self._private_ip

    @private_ip.setter
    def private_ip(self, private_ip):
        """
        Sets the private_ip of this LaunchDbSystemBase.
        A private IP address of your choice. Must be an available IP address within the subnet's CIDR.
        If you don't specify a value, Oracle automatically assigns a private IP address from the subnet.


        :param private_ip: The private_ip of this LaunchDbSystemBase.
        :type: str
        """
        self._private_ip = private_ip

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ContainerImageLayer(object):
    """
    The container image layer metadata.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ContainerImageLayer object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param digest:
            The value to assign to the digest property of this ContainerImageLayer.
        :type digest: str

        :param size_in_bytes:
            The value to assign to the size_in_bytes property of this ContainerImageLayer.
        :type size_in_bytes: int

        :param time_created:
            The value to assign to the time_created property of this ContainerImageLayer.
        :type time_created: datetime

        """
        self.swagger_types = {
            'digest': 'str',
            'size_in_bytes': 'int',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'digest': 'digest',
            'size_in_bytes': 'sizeInBytes',
            'time_created': 'timeCreated'
        }

        self._digest = None
        self._size_in_bytes = None
        self._time_created = None

    @property
    def digest(self):
        """
        **[Required]** Gets the digest of this ContainerImageLayer.
        The sha256 digest of the image layer.


        :return: The digest of this ContainerImageLayer.
        :rtype: str
        """
        return self._digest

    @digest.setter
    def digest(self, digest):
        """
        Sets the digest of this ContainerImageLayer.
        The sha256 digest of the image layer.


        :param digest: The digest of this ContainerImageLayer.
        :type: str
        """
        self._digest = digest

    @property
    def size_in_bytes(self):
        """
        **[Required]** Gets the size_in_bytes of this ContainerImageLayer.
        The size of the layer in bytes.


        :return: The size_in_bytes of this ContainerImageLayer.
        :rtype: int
        """
        return self._size_in_bytes

    @size_in_bytes.setter
    def size_in_bytes(self, size_in_bytes):
        """
        Sets the size_in_bytes of this ContainerImageLayer.
        The size of the layer in bytes.


        :param size_in_bytes: The size_in_bytes of this ContainerImageLayer.
        :type: int
        """
        self._size_in_bytes = size_in_bytes

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ContainerImageLayer.
        An RFC 3339 timestamp indicating when the layer was created.


        :return: The time_created of this ContainerImageLayer.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ContainerImageLayer.
        An RFC 3339 timestamp indicating when the layer was created.


        :param time_created: The time_created of this ContainerImageLayer.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_format_attribute import AbstractFormatAttribute
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AvroFormatAttribute(AbstractFormatAttribute):
    """
    The AVRO format attribute.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AvroFormatAttribute object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.AvroFormatAttribute.model_type` attribute
        of this class is ``AVRO_FORMAT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this AvroFormatAttribute.
            Allowed values for this property are: "JSON_FORMAT", "CSV_FORMAT", "AVRO_FORMAT"
        :type model_type: str

        :param is_file_pattern:
            The value to assign to the is_file_pattern property of this AvroFormatAttribute.
        :type is_file_pattern: bool

        :param compression:
            The value to assign to the compression property of this AvroFormatAttribute.
        :type compression: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'is_file_pattern': 'bool',
            'compression': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'is_file_pattern': 'isFilePattern',
            'compression': 'compression'
        }

        self._model_type = None
        self._is_file_pattern = None
        self._compression = None
        self._model_type = 'AVRO_FORMAT'

    @property
    def compression(self):
        """
        Gets the compression of this AvroFormatAttribute.
        The compression for the file.


        :return: The compression of this AvroFormatAttribute.
        :rtype: str
        """
        return self._compression

    @compression.setter
    def compression(self, compression):
        """
        Sets the compression of this AvroFormatAttribute.
        The compression for the file.


        :param compression: The compression of this AvroFormatAttribute.
        :type: str
        """
        self._compression = compression

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
